@@ -1,14 +1,13 @@
 package mr
 
 import (
-	"bytes"
-	"io"
 	"os"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
 	"gitlab.com/gitlab-org/cli/commands/cmdtest"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
+	"gitlab.com/gitlab-org/cli/test"
 )
 
 func TestMain(m *testing.M) {
@@ -23,18 +22,7 @@ func TestMrCmd_noARgs(t *testing.T) {
 
 	assert.Nil(t, NewCmdMR(&cmdutils.Factory{}).Execute())
 
-	outC := make(chan string)
-	// copy the output in a separate goroutine so printing can't block indefinitely
-	go func() {
-		var buf bytes.Buffer
-		_, _ = io.Copy(&buf, r)
-		outC <- buf.String()
-	}()
-
-	// back to normal state
-	w.Close()
-	os.Stdout = old // restoring the real stdout
-	out := <-outC
+	out := test.ReturnBuffer(old, r, w)
 
 	assert.Contains(t, out, "Use \"mr [command] --help\" for more information about a command.\n")
 }
