@@ -4,7 +4,7 @@ import (
 	"encoding/json"
 	"fmt"
 
-	"github.com/MakeNowJust/heredoc"
+	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
 	"github.com/xanzy/go-gitlab"
 	"gitlab.com/gitlab-org/cli/api"
@@ -42,13 +42,13 @@ func NewCmdExport(f *cmdutils.Factory, runE func(opts *ExportOpts) error) *cobra
 
 	cmd := &cobra.Command{
 		Use:     "export",
-		Short:   "Export project or group variables.",
+		Short:   "Export variables from a project or group.",
 		Aliases: []string{"ex"},
 		Args:    cobra.ExactArgs(0),
 		Example: heredoc.Doc(`
 			glab variable export
 			glab variable export --per-page 1000 --page 1
-      glab variable export --group gitlab-org
+			glab variable export --group gitlab-org
 			glab variable export --group gitlab-org --per-page 1000 --page 1
 		`),
 		RunE: func(cmd *cobra.Command, args []string) (err error) {
